# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# Test suite needs patching if we have Test::More < 0.88
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION) < 0.88 ? 1 : 0);' 2>/dev/null || echo 0)

Name:		perl-Data-Tumbler
Version:	0.010
Release:	5.%{__distinit}%{__distvers}
Summary:	Dynamic generation of nested combinations
Group:		Development/Libraries
License:	GPL+ or Artistic
URL:		http://search.cpan.org/dist/Data-Tumbler/
Source0:	http://search.cpan.org/CPAN/authors/id/R/RE/REHSACK/Data-Tumbler-%{version}.tar.gz
Patch0:		Data-Tumbler-0.010-old-Test::More.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
# Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module
BuildRequires:	perl(Carp)
BuildRequires:	perl(Storable)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(List::Util)
BuildRequires:	perl(Test::More)
# Asks for version 0.33 but tested OK with 0.11
BuildRequires:	perl(Test::Most) >= 0.11
BuildRequires:	perl(Time::HiRes)
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
The tumble() method calls a sequence of 'provider' code references, each of
which returns a hash. The first provider is called and then, for each hash item
it returns, the tumble() method recurses to call the next provider. The
recursion continues until there are no more providers to call, at which point
the consumer code reference is called. Effectively the providers create a tree
of combinations and the consumer is called at the leaves of the tree. If a
provider returns no items then that part of the tree is pruned. Further
providers, if any, are not called and the consumer is not called.

During a call to tumble() three values are passed down through the tree and
into the consumer: path, context, and payload. The path and context are derived
from the names and values of the hashes returned by the providers. Typically
the path defines the current "path" through the tree of combinations. The
providers are passed the current path, context, and payload. The payload is
cloned at each level of recursion so that any changes made to it by providers
are only visible within the scope of the generated sub-tree.

%prep
%setup -q -n Data-Tumbler-%{version}

# Test suite needs patching if we have Test::More < 0.88
%if %{old_test_more}
%patch0
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} %{buildroot}

%check
make test

%clean
rm -rf %{buildroot}

%files
%if 0%{?_licensedir:1}
%license ARTISTIC-1.0 GPL-1 LICENSE
%else
%doc ARTISTIC-1.0 GPL-1 LICENSE
%endif
%doc Changes README
%{perl_vendorlib}/Data/
%{_mandir}/man3/Data::Tumbler.3*

%changelog
* Mon Aug 15 2016 Paul Howarth <paul@city-fan.org> - 0.010-5
- BR: perl-generators where available
- Simplify find command using -delete

* Mon Jun 29 2015 Paul Howarth <paul@city-fan.org> - 0.010-3
- Perl 5.22 rebuild

* Fri Mar 27 2015 Paul Howarth <paul@city-fan.org> - 0.010-1
- Update to 0.010
  - Relax minimum perl to 5.6 since it runs fine in LMU on 5.6
  - Add POD sections for author, support, copyright, ...
  - Fix tests for $] < 5.008
- Update patch for building with Test::More < 0.88

* Tue Jan  6 2015 Paul Howarth <paul@city-fan.org> - 0.008-1
- Update to 0.008
  - Reflect CPAN RT#100805 recommendation in LICENSE

* Mon Dec 15 2014 Paul Howarth <paul@city-fan.org> - 0.007-1
- Update to 0.007
  - Add GPL-1 license text as it's fulfilling basic requirements

* Tue Dec  9 2014 Paul Howarth <paul@city-fan.org> - 0.006-1
- Update to 0.006
  - Improve Kwalitee
  - Deploy correct licenses
  - Rewrite Changes according to CPAN::Changes::Spec
  - Add rough documentation in Pod
- This release by REHSACK → update source URL

* Tue Sep 16 2014 Paul Howarth <paul@city-fan.org> - 0.005-4
- Perl 5.20 rebuild

* Mon Mar 24 2014 Paul Howarth <paul@city-fan.org> - 0.005-1
- Update to 0.005
  - Make a test from more detailed example in 0.004
- Package upstream's new README file
- BR: perl(List::Util) for new test
- Update patch for building with Test::More < 0.88

* Sun Mar 23 2014 Paul Howarth <paul@city-fan.org> - 0.004-1
- Update to 0.004
  - Improve the docs with a more detailed example

* Fri Mar 21 2014 Paul Howarth <paul@city-fan.org> - 0.003-1
- Initial RPM version
